@@ -5,7 +5,7 @@ import sys
 import numpy as np
 import scipy as sc
 import pandas as pd
-import Path
+from pathlib import Path
 import copy
 import re
 
@@ -120,6 +120,9 @@ class mainFormat(qtWidget.QWidget):
         self.showDialog(disclaimer, 'About')
             
     def fitWaveAction(self):
+        if self._th_fw.is_alive():
+            self.showDialog("plottin already running", 'Info')
+            return
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
@@ -133,6 +136,9 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("Wrong file/files extension. Use only one kind at time", "Alert")
             
     def mutWaveAction(self):
+        if self._th_mw.is_alive():
+            self.showDialog("plottin already running", 'Info')
+            return
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
@@ -146,6 +152,9 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("Wrong file/files extension. Use only one kind at time", "Alert")
             
     def popGrowthAction(self):
+        if self._th_pg.is_alive():
+            self.showDialog("plottin already running", 'Info')
+            return
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
@@ -159,6 +168,9 @@ class mainFormat(qtWidget.QWidget):
             self.showDialog("Wrong file/files extension. Use only one kind at time", "Alert")
             
     def combinedMutWave(self):
+        if self._th_cp.is_alive():
+            self.showDialog("plottin already running", 'Info')
+            return
         fname = qtWidget.QFileDialog.getOpenFileNames(None, 'Open file', "Z://","Data File (*.npz)")[0] 
         if len(fname) == 0:
             self.showDialog("No file selected!", "Alert")
@@ -380,6 +392,15 @@ class mainFormat(qtWidget.QWidget):
         for i in self.s_ID:
             layout.addRow(qtWidget.QLabel("ID: " + str(i)), qtWidget.QLabel())
         
+        if self._th_pg.is_alive():
+            layout.addRow(qtWidget.QLabel("population growth plot", qtWidget.QLabel()))
+        if self._th_cp.is_alive():
+            layout.addRow(qtWidget.QLabel("combined plot", qtWidget.QLabel()))
+        if self._th_mw.is_alive():
+            layout.addRow(qtWidget.QLabel("mutation wave", qtWidget.QLabel()))
+        if self._th_fw.is_alive():
+            layout.addRow(qtWidget.QLabel("fitness wave", qtWidget.QLabel()))
+        
         threadTabUI.setLayout(layout)
         return threadTabUI
     
